#[non_exhaustive]pub enum ConvertError<'src> {
Syntax {
syntax_errors: Vec<SyntaxError>,
src: Cow<'src, str>,
},
Semantic {
semantic_errors: Vec<SemanticError>,
src: Cow<'src, str>,
},
Unknown,
}Expand description
Represents an error that occurred while converting MinTyML.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
Syntax
The conversion failed due to one or more syntax errors.
Semantic
The conversion failed due to one or more semantic errors.
Unknown
The conversion failed for some other reason.
Implementations
Sourceimpl<'src> ConvertError<'src>
impl<'src> ConvertError<'src>
Sourcepub fn to_static(self) -> ConvertError<'static>
pub fn to_static(self) -> ConvertError<'static>
Copies all borrowed data so the error can outlive the source str.